@@ -1,6 +1,6 @@
 # from scapy.all import *
 from scapy.layers.inet import TCP, IP, UDP
-from scapy.sendrecv import sniff, AsyncSniffer
+from scapy.sendrecv import sniff
 from threading import Thread
 import pandas as pd
 import numpy as np
@@ -159,15 +159,9 @@ class Flowmeter:
             callback=self.process_session,
             sess_function=self._get_sessions
         )
-        # sniff(session=FlowSession, offline=self.offline, session_kwargs=session_kwargs)
-        sniffer = AsyncSniffer(session=FlowSession, offline=self.offline, session_kwargs=session_kwargs)
-        try:
-            sniffer.start()
-            while True:
-                pass
-        except KeyboardInterrupt:
-            print('Stopping sniffer')
-            results = sniffer.stop()
+        print('Sniffing; ctrl+c to stop.')
+        results = sniff(session=FlowSession, offline=self.offline, session_kwargs=session_kwargs)
+        print('Stopping...')
         self.process_session(results)
         
 
@@ -1134,7 +1128,7 @@ class Flowmeter:
             return 0 
 
         a = pd.DataFrame()
-        a["time"] = pd.to_datetime(df["time"].astype(float), unit="s")
+        a["time"] = pd.to_datetime(df["time"].astype(float).sort_values(), unit="s")
         a["count"] = 1
         a.set_index(["time"], inplace=True)
         a["rolling"] = a.rolling('100ms').sum()
